#ifndef __RK4_H__
#define __RK4_H__

// -------------------------------------------------------------------------------------------------------
// Funkcja wykonuje, metod Eulera,
// jeden krok cakowania wektorowego rwnania roniczkowego zwyczajnego:
//
//  dY/dx = Fun(x,Y),    Y(x0)=Y0
//
// Parametry formalne:
// x0 - warto startowa zm. niezalenej
// y0 - warto startowa zm. zalenej (tablica n-elementowa)
// h  - krok cakowania
// n  - liczba rwna
// fun(x,y,prawastr) - nazwa funkcji obliczajcej prawe strony
// y1 - obliczona warto zmiennej zalenej w punkcie x0+h
//      (tablica n-elementowa)

void Euler( double x0, double y0[], double h, int n, void (*fun)(double, double*, double*), double y1[] );


// --------------------------------------------------------------------------
// Funkcja wykonuje, metod Rungego-Kutty Iv-ego rzdu,
// jeden krok cakowania skalarnego rwnania roniczkowego zwyczajnego:
//
//  dy/dx = fun(x,y),    y(x0)=y0
//
// Parametry formalne:
// x0 - warto startowa zm. niezalenej
// y0 - warto startowa zm. zalenej
// h  - krok cakowania
// fun(x,y) - nazwa funkcji obliczajcej prawe strony
// y1 - obliczona warto zmiennej zalenej w punkcie x0+h

double rk4( double x0, double y0, double h, double (*fun)(double, double));



// --------------------------------------------------------------------------
// Funkcja wykonuje, metod Rungego-Kutty IV-tego rzedu,
// jeden krok cakowania wektorowego rwnania roniczkowego zwyczjanego:
//
//  dY/dx = Fun(x,Y),    Y(x0)=Y0
//
// Parametry formalne:
// x0 - warto startowa zm. niezalenej
// y0 - warto startowa zm. zalenej (tablica n-elementowa)
// h  - krok cakowania
// n  - liczba rwna
// fun(x,y,prawastr) - nazwa funkcji obliczajcej prawe strony
// y1 - obliczona warto zmiennej zalenej w punkcie x0+h
//      (tablica n-elementowa)

void vrk4( double x0, double y0[], double h, int n, void (*fun)(double, double*, double*), double y1[] );


#endif